import { API_URL } from '$env/static/private';
import { redirect } from '@sveltejs/kit';
import type { PageServerLoad } from './$types';

import type { Chapter, LeaderboardEvent } from '$lib/types';

import { handleRedirect } from '$lib/utils';

export const load: PageServerLoad = async ({ url, locals: { user }, fetch, params: { chapterId } }) => {
	if (!user) redirect(302, handleRedirect('login', url));

	let res = await fetch(`${API_URL}/chapter/${chapterId}`)

	if (!res.ok) redirect(302, `/chapters/${chapterId}`);

	const chapter: Chapter = await res.json();

	if (!(chapter.start && chapter.end)) redirect(302, `/chapters/${chapter.id}`);

	res = await fetch(`${API_URL}/leaderboard/${chapter.id}`);

	let leaderboard: LeaderboardEvent | undefined = undefined;

	if (!res.ok) leaderboard = undefined;

	leaderboard = await res.json();

	return {
		title: `${chapter.name} - Classement`,
		leaderboard
	};
};
